@@ -1,33 +1,31 @@
 package main
 
 import (
+	"github.com/stretchr/testify/assert"
 	"os"
 	"testing"
 
-	"github.com/jfrog/jfrog-cli-core/utils/coreutils"
-	coreTests "github.com/jfrog/jfrog-cli-core/utils/tests"
+	coreTests "github.com/jfrog/jfrog-cli-core/v2/utils/tests"
 	"github.com/jfrog/jfrog-cli/utils/tests"
 	"github.com/jfrog/jfrog-client-go/utils/log"
 	clientTests "github.com/jfrog/jfrog-client-go/utils/tests"
 )
 
 const (
-	JfrogTestsHome      = ".jfrogTest"
 	CliIntegrationTests = "github.com/jfrog/jfrog-cli"
 )
 
 func TestUnitTests(t *testing.T) {
-	oldHome, err := coreTests.SetJfrogHome()
+	// Create temp jfrog home
+	cleanUpJfrogHome, err := coreTests.SetJfrogHome()
 	if err != nil {
 		log.Error(err)
 		os.Exit(1)
 	}
-	defer os.Setenv(coreutils.HomeDir, oldHome)
 	// Clean from previous tests.
-	coreTests.CleanUnitTestsJfrogHome()
-	defer coreTests.CleanUnitTestsJfrogHome()
+	defer cleanUpJfrogHome()
 
 	packages := clientTests.GetTestPackages("./...")
 	packages = clientTests.ExcludeTestsPackage(packages, CliIntegrationTests)
-	clientTests.RunTests(packages, *tests.HideUnitTestLog)
+	assert.NoError(t, clientTests.RunTests(packages, *tests.HideUnitTestLog))
 }
